@@ -75,14 +75,13 @@ OC.L10N.register(
     "Creating subscription …" : "جاري انشاء اشتراك  …",
     "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
-    "Untitled event" : "فعالية بدون اسم",
     "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
     "Filename" : "اسم الملف",
     "Calendar to import into" : "تقويم للاستيراد اليه",
     "Cancel" : "إلغاء",
-    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
+    "_Import calendar_::_Import calendars_" : ["استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم","استيراد التقويم"],
     "Automatic" : "تلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "New setting was not saved successfully." : "لم يتم حفظ الاعدادات الجديدة.",
@@ -123,8 +122,7 @@ OC.L10N.register(
     "on" : "في",
     "at" : "في",
     "+ Add reminder" : "+ اضافة تذكير",
-    "_second_::_seconds_" : ["ثانية","ثانية","ثواني","ثواني","ثواني"],
-    "No reminders yet" : "لا يوجد تذكير بعد",
+    "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
     "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
     "Free" : "متوفر",
     "Busy (tentative)" : "مشغول (حاليا)",
@@ -133,6 +131,7 @@ OC.L10N.register(
     "Unknown" : "غير معروف",
     "Create Talk room for this event" : "انشاء غرفة تحدث لهذه الفعالية.",
     "Show busy times" : "اظهار الاوقات الممتلئة",
+    "No attendees yet" : "لا يوجد حضور بعد",
     "Successfully appended link to talk room to description." : "تم اضافة الرابط في وصف غرفة التحدث بنجاح.",
     "Error creating Talk room" : "خطأ في انشاء غرفة تحدث",
     "Chairperson" : "الرئيس",
@@ -141,7 +140,6 @@ OC.L10N.register(
     "Non-participant" : "غير مشارك",
     "Remove attendee" : "طرد الحاضر",
     "No match found" : "لا يوجد تطابق",
-    "No attendees yet" : "لا يوجد حضور بعد",
     "(organizer)" : "(منظم)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "لإرسال الدعوات والتعامل مع الاستجابات [linkopen]اضف بريدك الالكتروني في ملفك الشخصي[linkclose].",
     "Remove color" : "حذف اللون",
@@ -151,6 +149,8 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "منذ تاريخ {startDate} في {startTime}",
     "to {endDate}" : "إلى تاريخ {endDate}",
     "to {endDate} at {endTime}" : "إلى {endDate} في {endTime}",
+    "Repeat" : "التكرار",
+    "Save" : "حفظ",
     "End repeat" : "نهاية التكرار",
     "Select to end repeat" : "اختر نهاية التكرار",
     "never" : "بتاتاً",
@@ -163,23 +163,19 @@ OC.L10N.register(
     "second to last" : "الثاني إلى الاخير",
     "last" : "الاخير",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغيير قانون التكرار يتم تعيينه لهذا ولظهور المستقبل فقط.",
-    "Repeat" : "التكرار",
     "Repeat every" : "تكرار كل",
     "By day of the month" : "يوم من الشهر",
     "On the" : "في الـ",
-    "_year_::_years_" : ["سنه","سنه","سنوات","سنوات","سنوات"],
+    "_year_::_years_" : ["سنه","سنه","سنه","سنوات","سنوات","سنوات"],
     "Monday" : "الإثنين",
     "weekday" : "ايام الاسبوع",
     "weekend day" : "يوم نهاية الاسبوع",
-    "Summary" : "المُلخَّص",
     "More" : "المزيد",
-    "Save" : "حفظ",
     "Update" : "حدث",
     "Update this occurrence" : "تغيير هذا الظهور",
     "Update this and all future" : "تغيير هذا والمستقبل",
     "Public calendar does not exist" : "التقويم العام غير موجود",
     "Maybe the share was deleted or has expired?" : "لربما المشاركة محذوفة أو منتهية؟",
-    "Please select a timezone:" : "يرجى اختيار المنطقة الزمنية:",
     "Pick a time" : "اختر وقت",
     "Pick a date" : "اختر تاريخ",
     "from {formattedDate}" : "من {formattedDate}",
@@ -191,7 +187,7 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} في {formattedTime}",
     "Please enter a valid date" : "اختر تاريخ صحيح",
     "Please enter a valid date and time" : "اختر تاريخ ووقت صحيح",
-    "Type to search timezone" : "ابحث عن منطقة زمنية",
+    "Global" : "عالمي",
     "Personal" : "شخصي",
     "No more events today" : "لا يوجد المزيد من الفعاليات اليوم",
     "No upcoming events" : "ليس هناك فعاليات قادمة",
@@ -205,7 +201,6 @@ OC.L10N.register(
     "Delete this and all future" : "حذف هذا الظهور والجميع في الستقبل",
     "Details" : "التفاصيل",
     "Attendees" : "المشاركون",
-    "Reminders" : "تذكيرات",
     "Close" : "إغلاق",
     "Show more details" : "اظهار المزيد من التفاصيل",
     "Subscribe to {name}" : "اشتراك مع {name}",
@@ -244,6 +239,7 @@ OC.L10N.register(
     "in {monthNames}" : "في {monthNames}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "في {monthNames} في الـ {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "حتى {untilDate}",
+    "Untitled event" : "فعالية بدون اسم",
     "Untitled task" : "مهمة بدون اسم",
     "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
     "%n more" : "%n المزيد",
@@ -361,7 +357,6 @@ OC.L10N.register(
     "Wine tasting" : "تذوق",
     "Golf" : "الجولف",
     "Dinner" : "عشاء",
-    "Lunch" : "غداء",
-    "Global" : "عالمي"
+    "Lunch" : "غداء"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
