@@ -26,18 +26,17 @@ OC.L10N.register(
     "Email" : "email",
     "Unknown" : "Desconozse",
     "All day" : "Tol día",
+    "Repeat" : "Repitir",
+    "Save" : "Guardar",
     "never" : "enxamás",
     "after" : "dempués",
-    "Repeat" : "Repitir",
     "Monday" : "Llunes",
-    "Summary" : "Sumariu",
     "More" : "Más",
-    "Save" : "Guardar",
     "Update" : "Anovar",
+    "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
-    "Reminders" : "Recordatorios",
     "Close" : "Zarrar",
     "Anniversary" : "Aniversariu",
     "Week {number} of {year}" : "Selmana {number} del {year}",
@@ -54,7 +53,6 @@ OC.L10N.register(
     "Categories" : "Estayes",
     "Presentation" : "Presentación",
     "Office" : "Oficina",
-    "Mail" : "Corréu",
-    "Global" : "Global"
+    "Mail" : "Corréu"
 },
 "nplurals=2; plural=(n != 1);");
