@@ -94,15 +94,15 @@ OC.L10N.register(
     "Free" : "Digoust",
     "Busy" : "O labourat",
     "Unknown" : "Dianv",
+    "Save" : "Enrollañ",
     "never" : "james",
     "after" : "goude",
     "first" : "kentañ",
     "third" : "trede",
     "Monday" : "Lun",
-    "Summary" : "Diverrañ",
     "More" : "Muioc'h",
-    "Save" : "Enrollañ",
     "Update" : "Hizivaat",
+    "Global" : "Hollek",
     "Personal" : "Personel",
     "[Today]" : "[Hiziv]",
     "[Tomorrow]" : "[Warc'hoazh]",
@@ -230,7 +230,6 @@ OC.L10N.register(
     "Wine tasting" : "Tañva gwin",
     "Golf" : "Golf",
     "Dinner" : "Koan",
-    "Lunch" : "Pred kreisteiz",
-    "Global" : "Hollek"
+    "Lunch" : "Pred kreisteiz"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
