@@ -77,7 +77,8 @@ OC.L10N.register(
     "Creating subscription …" : "S'està creant la subscripció …",
     "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
-    "Untitled event" : "Esdeveniment sense títol",
+    "Trash bin" : "Paperera",
+    "Name" : "Nom",
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
     "Import calendars" : "Importar calendaris",
     "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
@@ -97,7 +98,7 @@ OC.L10N.register(
     "or" : "o",
     "Navigation" : "Navegació",
     "Previous period" : "Període anterior",
-    "Next period" : "Següent període",
+    "Next period" : "Període següent",
     "Views" : "Vistes",
     "Day view" : "Vista de dia",
     "Week view" : "Vista de setmana",
@@ -135,32 +136,33 @@ OC.L10N.register(
     "_hour_::_hours_" : ["hora","hores"],
     "_day_::_days_" : ["dia","dies"],
     "_week_::_weeks_" : ["setmana","setmanes"],
-    "No reminders yet" : "Encara no hi ha recordatoris",
     "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
     "Free" : "Lliure",
-    "Busy (tentative)" : "Ocupat (temptativament)",
+    "Busy (tentative)" : "Ocupat (provisional)",
     "Busy" : "Ocupat",
-    "Out of office" : "Fora de la oficina",
+    "Out of office" : "Fora de l'oficina",
     "Unknown" : "Desconegut",
     "Create Talk room for this event" : "Crear una sala a Talk per a aquest event",
     "Show busy times" : "Mostra els horaris ocupats",
+    "No attendees yet" : "Encara no hi ha cap participant",
     "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala del Talk a la descripció de l'event.",
     "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
-    "Chairperson" : "S'està convocant",
-    "Required participant" : "Participant necessari",
-    "Optional participant" : "Participant opcional",
-    "Non-participant" : "No-participant",
-    "Remove attendee" : "Treu el participant",
-    "No match found" : "No s'ha trobat res",
-    "No attendees yet" : "Encara sense participants",
-    "(organizer)" : "(organitzador)",
-    "Remove color" : "Treu el color",
-    "Event title" : "Títol de l'event",
+    "Chairperson" : "Organització",
+    "Required participant" : "Participació obligatòria",
+    "Optional participant" : "Participació opcional",
+    "Non-participant" : "Sense participació",
+    "Remove attendee" : "Suprimeix el participant",
+    "No match found" : "No s'ha trobat cap coincidència",
+    "(organizer)" : "(organitza l'esdeveniment)",
+    "Remove color" : "Suprimeix el color",
+    "Event title" : "Títol de l'esdeveniment",
     "All day" : "Tot el dia",
     "from {startDate}" : "del {startDate}",
     "from {startDate} at {startTime}" : "de {startDate} a {startTime}",
     "to {endDate}" : "fins al {endDate}",
     "to {endDate} at {endTime}" : "fins al {endDate} a les {endTime}",
+    "Repeat" : "Repeteix",
+    "Save" : "Desa",
     "End repeat" : "Finalitza la repetició",
     "Select to end repeat" : "Seleccioneu per finalitzar repetició",
     "never" : "mai",
@@ -174,7 +176,6 @@ OC.L10N.register(
     "second to last" : "penúltim",
     "last" : "últim",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
-    "Repeat" : "Repeteix",
     "Repeat every" : "Repetir cada",
     "By day of the month" : "Per dia del mes",
     "On the" : "Al",
@@ -183,16 +184,13 @@ OC.L10N.register(
     "Monday" : "Dilluns",
     "weekday" : "dia de la setmana",
     "weekend day" : "dia de cap de setmana",
-    "Summary" : "Resum",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest event no es del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
     "More" : "Més",
-    "Save" : "Desa",
     "Update" : "Actualitza",
     "Update this occurrence" : "Actualitza aquesta ocurrència",
     "Update this and all future" : "Actualitza aquesta i les futures",
     "Public calendar does not exist" : "No existeix un calendari públic",
     "Maybe the share was deleted or has expired?" : "Potser la compartició va ser esborrada o va expirar?",
-    "Please select a timezone:" : "Selecciona un fus horari",
     "Pick a time" : "Tria una hora",
     "Pick a date" : "Tria una data",
     "from {formattedDate}" : "de {formattedDate}",
@@ -204,10 +202,8 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
     "Please enter a valid date" : "Si us plau, escriu una data vàlida",
     "Please enter a valid date and time" : "Si us plau, escriu una data i hora vàlides",
-    "Type to search timezone" : "Comença a escriure per cercar un fus horari",
+    "Global" : "Global",
     "Personal" : "Personal",
-    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "La detecció automàtica de zona horària ha establert que la vostra zona horària és UTC.\nAixò probablement és el resultat d'una mesura de seguretat del vostre navegador web.\nEstabliu la vostra zona horària manualment a la configuració del calendari.",
-    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "No s'ha trobat la zona horària que heu establert ({timezoneId}) . Així que se us ha retornat a la UTC.\nDefiniu la vostra zona horària a la configuració i si us plau informeu d'aquest problema.",
     "No more events today" : "Avui no hi ha més esdeveniments",
     "No upcoming events" : "No hi ha propers esdeveniments",
     "Create a new event" : "Crea un esdeveniment nou",
@@ -220,7 +216,6 @@ OC.L10N.register(
     "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
     "Details" : "Detalls",
     "Attendees" : "Assistents",
-    "Reminders" : "Recordatoris",
     "Close" : "Tanca",
     "Show more details" : "Mostra'n més detalls",
     "Subscribe to {name}" : "Subscriure a {name}",
@@ -268,8 +263,10 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "al {monthNames} al {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "fins el {untilDate}",
     "_%n time_::_%n times_" : ["%n vegada","%n vegades"],
+    "Untitled event" : "Esdeveniment sense títol",
     "Untitled task" : "Tasca sense títol",
     "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
+    "Year" : "Any",
     "W" : "S",
     "%n more" : "%n més",
     "No events to display" : "No hi ha esdeveniments per visualitzar",
@@ -387,7 +384,6 @@ OC.L10N.register(
     "Wine tasting" : "Tasta de vins",
     "Golf" : "Golf",
     "Dinner" : "Sopar",
-    "Lunch" : "Dinar",
-    "Global" : "Global"
+    "Lunch" : "Dinar"
 },
 "nplurals=2; plural=(n != 1);");
