@@ -25,17 +25,17 @@ OC.L10N.register(
     "Settings & import" : "Gosodiadau a mewnforio",
     "Email" : "E-bost",
     "Unknown" : "Anhysbys",
+    "Repeat" : "Ailadrodd",
+    "Save" : "Cadw",
     "never" : "byth",
     "after" : "wedi",
-    "Repeat" : "Ailadrodd",
     "Monday" : "Llun",
     "More" : "Rhagor",
-    "Save" : "Cadw",
     "Update" : "Diweddaru",
+    "Global" : "Eang",
     "Personal" : "Personol",
     "Details" : "Manylion",
     "Attendees" : "Mynychwyr",
-    "Reminders" : "Nodau atgoffa",
     "Close" : "Cau",
     "Anniversary" : "Dathliad",
     "Week {number} of {year}" : "Wythnos {number} o {year}",
@@ -46,7 +46,6 @@ OC.L10N.register(
     "Description" : "Disgrifiad",
     "Confirmed" : "Cadarnhawyd",
     "Tentative" : "I'w gadarnhau",
-    "Mail" : "E-bost",
-    "Global" : "Eang"
+    "Mail" : "E-bost"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
