@@ -64,7 +64,6 @@ OC.L10N.register(
     "Creating calendar …" : "Opretter kalender…",
     "New calendar with task list" : "Ny kalender med opgaveliste",
     "Creating subscription …" : "Opretter abonnement…",
-    "Untitled event" : "Unavngiven begivenhed",
     "Import calendars" : "Importer kalendere",
     "Filename" : "Filnavn",
     "Cancel" : "Annullér",
@@ -94,6 +93,8 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "fra {startDate} kl {startTime}",
     "to {endDate}" : "til {endDate}",
     "to {endDate} at {endTime}" : "til {endDate} kl {endTime}",
+    "Repeat" : "Gentag",
+    "Save" : "Gem",
     "never" : "aldrig",
     "after" : "efter",
     "first" : "første",
@@ -102,25 +103,23 @@ OC.L10N.register(
     "fifth" : "femte",
     "second to last" : "næstsidste",
     "last" : "sidste",
-    "Repeat" : "Gentag",
     "_month_::_months_" : ["måned","måneder"],
     "_year_::_years_" : ["år","år"],
     "Monday" : "Mandag",
     "weekday" : "hverdag",
     "weekend day" : "weekenddag",
-    "Summary" : "Oversigt",
     "More" : "Mere",
-    "Save" : "Gem",
     "Update" : "Opdatér",
+    "Global" : "Global",
     "Personal" : "Personlig",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
-    "Reminders" : "Påmindelser",
     "Close" : "Luk",
     "Anniversary" : "Årsdag",
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Daily" : "Dagligt",
     "Weekly" : "Ugentligt",
+    "Untitled event" : "Unavngiven begivenhed",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
     "When shared hide this event" : "Når delt, skjul denne begivenhed",
@@ -134,7 +133,6 @@ OC.L10N.register(
     "Movie" : "Film",
     "Review" : "Gennemse",
     "Office" : "Kontor",
-    "Mail" : "Mail",
-    "Global" : "Global"
+    "Mail" : "Mail"
 },
 "nplurals=2; plural=(n != 1);");
