@@ -43,18 +43,17 @@ OC.L10N.register(
     "Email" : "Correo electrónico",
     "Unknown" : "Desconocido",
     "All day" : "Todo el día",
+    "Repeat" : "Repetir",
+    "Save" : "Guardar",
     "never" : "nunca",
     "after" : "después",
-    "Repeat" : "Repetir",
     "Monday" : "Lunes",
-    "Summary" : "Resumen",
     "More" : "Más",
-    "Save" : "Guardar",
     "Update" : "Actualizar",
+    "Global" : "Global",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
-    "Reminders" : "Recordatorios",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
@@ -70,7 +69,6 @@ OC.L10N.register(
     "Tentative" : "Tentativo",
     "Categories" : "Categoría",
     "Movie" : "Película",
-    "Mail" : "Correo Electrónico",
-    "Global" : "Global"
+    "Mail" : "Correo Electrónico"
 },
 "nplurals=2; plural=(n != 1);");
