@@ -47,18 +47,17 @@ OC.L10N.register(
     "On date" : "Kuupäeval",
     "Unknown" : "Teadmata",
     "All day" : "Kogu päev",
+    "Repeat" : "Korda",
+    "Save" : "Salvesta",
     "never" : "mitte kunagi",
     "after" : "pärast",
-    "Repeat" : "Korda",
     "Monday" : "Esmaspäev",
-    "Summary" : "Kokkuvõte",
     "More" : "Rohkem",
-    "Save" : "Salvesta",
     "Update" : "Uuenda",
+    "Global" : "Üldine",
     "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
     "Attendees" : "Osalejad",
-    "Reminders" : "Meelespead",
     "Close" : "Sulge",
     "Anniversary" : "Aastapäev",
     "Appointment" : "Kohtumine",
@@ -136,7 +135,6 @@ OC.L10N.register(
     "Skateboard" : "Rula",
     "Wine tasting" : "Veini degusteerimine",
     "Golf" : "Golf",
-    "Dinner" : "Õhtusöök",
-    "Global" : "Üldine"
+    "Dinner" : "Õhtusöök"
 },
 "nplurals=2; plural=(n != 1);");
