@@ -15,22 +15,21 @@ OC.L10N.register(
     "Cancel" : "Չեղարկել",
     "Email" : "Էլ․փոստ",
     "Unknown" : "Անհայտ",
+    "Repeat" : "Կրկնել",
+    "Save" : "Պահպանել",
     "never" : "երբեք",
     "after" : "հետո",
-    "Repeat" : "Կրկնել",
     "Monday" : "Երկուշաբթի",
     "More" : "Ավելի",
-    "Save" : "Պահպանել",
     "Update" : "Թարմացնել",
+    "Global" : "Ընդհանուր",
     "Personal" : "Անձնական",
     "Details" : "Մանրամասներ",
     "Attendees" : "Մասնակիցներ",
-    "Reminders" : "Հիշեցումներ",
     "Close" : "Փակել",
     "Location" : "Տեղակայություն",
     "Description" : "Նկարագրություն",
     "Confirmed" : "Հաստատված",
-    "Mail" : "Փոստ",
-    "Global" : "Ընդհանուր"
+    "Mail" : "Փոստ"
 },
 "nplurals=2; plural=(n != 1);");
