@@ -72,7 +72,6 @@ OC.L10N.register(
     "Creating subscription …" : "Membuat langganan …",
     "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
-    "Untitled event" : "Acara tanpa judul",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -124,7 +123,6 @@ OC.L10N.register(
     "_hour_::_hours_" : ["jam"],
     "_day_::_days_" : ["hari"],
     "_week_::_weeks_" : ["minggu"],
-    "No reminders yet" : "Belum ada pengingat",
     "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
@@ -133,6 +131,7 @@ OC.L10N.register(
     "Unknown" : "Tidak diketahui",
     "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
     "Show busy times" : "Tampilkan waktu sibuk",
+    "No attendees yet" : "Belum ada peserta",
     "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
     "Error creating Talk room" : "Galat membuat ruangan Talk",
     "Required participant" : "Partisipan wajib",
@@ -140,11 +139,12 @@ OC.L10N.register(
     "Non-participant" : "Bukan partisipan",
     "Remove attendee" : "Hapus peserta",
     "No match found" : "Tidak ditemukan kecocokan",
-    "No attendees yet" : "Belum ada peserta",
     "(organizer)" : "(penyelenggara)",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "All day" : "Sepanjang hari",
+    "Repeat" : "Ulang",
+    "Save" : "Simpan",
     "End repeat" : "Akhiri perulangan",
     "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
     "never" : "tidak pernah",
@@ -156,7 +156,6 @@ OC.L10N.register(
     "fifth" : "ke-5",
     "second to last" : "kedua terakhir",
     "last" : "terakhir",
-    "Repeat" : "Ulang",
     "Repeat every" : "Ulang setiap",
     "By day of the month" : "Berdasarkan hari pada bulan",
     "On the" : "Pada",
@@ -165,25 +164,18 @@ OC.L10N.register(
     "Monday" : "Senin",
     "weekday" : "akhir pekan",
     "weekend day" : "akhir pekan",
-    "Summary" : "Kesimpulan",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
     "More" : "Lainnya",
-    "Save" : "Simpan",
     "Update" : "Perbarui",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
-    "Please select a timezone:" : "Pilih zona waktu:",
     "Pick a time" : "Pilih waktu",
     "Pick a date" : "Pilih tanggal",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
-    "Type to search timezone" : "Tulis dan cari zona waktu",
     "Personal" : "Pribadi",
-    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Deteksi otomatis menunjukkan zona waktu Anda adalah UTC.\nHal ini dikarenakan hasil dari pengaturan pada peramban web Anda.\nSilakan setel zona waktu Anda pada setelan kalender.",
-    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Konfigurasi zona waktu ({timezoneId}) tidak ditemukan. Kembali menggunakan UTC.\nSilakan ubah zona waktu Anda pada pengaturan dan laporkan isu ini.",
     "Details" : "Detail",
     "Attendees" : "Peserta",
-    "Reminders" : "Pengingat",
     "Close" : "Tutup",
     "Show more details" : "Tampilkan detail lain",
     "Subscribe to {name}" : "Berlangganan ke {name}",
@@ -227,6 +219,7 @@ OC.L10N.register(
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
     "until {untilDate}" : "sampai {untilDate}",
     "_%n time_::_%n times_" : ["%n kali"],
+    "Untitled event" : "Acara tanpa judul",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
