@@ -76,7 +76,6 @@ OC.L10N.register(
     "Creating subscription …" : "Útbý áskrift …",
     "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
-    "Untitled event" : "Ónefndur atburður",
     "Import calendars" : "Flytja inn dagatöl",
     "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
     "Filename" : "Skráarheiti",
@@ -129,7 +128,6 @@ OC.L10N.register(
     "_hour_::_hours_" : ["klukkustund","klukkustundir"],
     "_day_::_days_" : ["dagur","dagar"],
     "_week_::_weeks_" : ["vika","vikur"],
-    "No reminders yet" : "Engar áminningar ennþá",
     "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
     "Free" : "Laus",
     "Busy (tentative)" : "Upptekinn (með fyrirvara)",
@@ -137,13 +135,13 @@ OC.L10N.register(
     "Out of office" : "Ekki á staðnum",
     "Unknown" : "Óþekkt",
     "Show busy times" : "Sýna upptekinn tíma",
+    "No attendees yet" : "Engir þáttakendur ennþá",
     "Chairperson" : "Fundarstjóri",
     "Required participant" : "Nauðsynlegur þáttakandi",
     "Optional participant" : "Aukaþáttakandi",
     "Non-participant" : "Ekki þáttakandi",
     "Remove attendee" : "Fjarlægja þáttakanda",
     "No match found" : "Fann engar samsvaranir",
-    "No attendees yet" : "Engir þáttakendur ennþá",
     "(organizer)" : "(skipuleggjandi)",
     "Remove color" : "Fjarlægja lit",
     "Event title" : "Titill atburðar",
@@ -152,6 +150,8 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "frá {startDate} klukkan {startTime}",
     "to {endDate}" : "til {endDate}",
     "to {endDate} at {endTime}" : "til {endDate} klukkan {endTime}",
+    "Repeat" : "Endurtaka",
+    "Save" : "Vista",
     "End repeat" : "Hætta endurtekningu",
     "Select to end repeat" : "Veldu til að hætta endurtekningu",
     "never" : "aldrei",
@@ -163,7 +163,6 @@ OC.L10N.register(
     "fourth" : "fjórða",
     "fifth" : "fimmta",
     "last" : "síðasta",
-    "Repeat" : "Endurtaka",
     "Repeat every" : "Endurtaka",
     "By day of the month" : "Eftir degi mánaðarins",
     "On the" : "Þann",
@@ -172,15 +171,12 @@ OC.L10N.register(
     "Monday" : "Mánudagur",
     "weekday" : "vinnudagur",
     "weekend day" : "helgardagur",
-    "Summary" : "Samantekt",
     "More" : "Meira",
-    "Save" : "Vista",
     "Update" : "Uppfæra",
     "Update this occurrence" : "Uppfæra þetta tilviki",
     "Update this and all future" : "Uppfæra þetta og öll síðari",
     "Public calendar does not exist" : "Opinbert dagatal er ekki til",
     "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
-    "Please select a timezone:" : "Veldu tímabelti:",
     "Pick a time" : "Veldu tíma",
     "Pick a date" : "Veldu dagsetningu",
     "from {formattedDate}" : "frá {formattedDate}",
@@ -188,7 +184,7 @@ OC.L10N.register(
     "on {formattedDate}" : "þann {formattedDate}",
     "Please enter a valid date" : "Settu inn gilda dagsetningu",
     "Please enter a valid date and time" : "Settu inn gilda dags- og tímasetningu",
-    "Type to search timezone" : "Skrifaðu hér til að leita að tímabelti",
+    "Global" : "Víðvært",
     "Personal" : "Persónulegt",
     "[Today]" : "[Í dag]",
     "[Tomorrow]" : "[Á morgun]",
@@ -197,7 +193,6 @@ OC.L10N.register(
     "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
     "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
-    "Reminders" : "Áminningar",
     "Close" : "Loka",
     "Show more details" : "Sýna frekari upplýsingar",
     "Subscribe to {name}" : "Panta áskrift að {name}",
@@ -226,6 +221,7 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "í {monthNames} þann {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "þangað til {untilDate}",
     "_%n time_::_%n times_" : ["%n sinni","%n sinnum"],
+    "Untitled event" : "Ónefndur atburður",
     "Untitled task" : "Ónefnt verkefni",
     "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
     "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
@@ -337,7 +333,6 @@ OC.L10N.register(
     "Wine tasting" : "Vínsmökkun",
     "Golf" : "Golf",
     "Dinner" : "Kvöldverður",
-    "Lunch" : "Hádegisverður",
-    "Global" : "Víðvært"
+    "Lunch" : "Hádegisverður"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
