@@ -78,7 +78,12 @@ OC.L10N.register(
     "Creating subscription …" : "購読を作成中 …",
     "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
-    "Untitled event" : "無題のイベント",
+    "Trash bin" : "ごみ箱",
+    "You do not have any deleted elements." : "削除された資格情報はありません",
+    "Name" : "名前",
+    "Deleted" : "削除済み",
+    "Restore" : "復元",
+    "Delete permanently" : "完全に削除する",
     "Could not update calendar order." : "カレンダーの順番を更新できません。",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
@@ -103,6 +108,7 @@ OC.L10N.register(
     "Day view" : "日表示",
     "Week view" : "週表示",
     "Month view" : "月表示",
+    "List view" : "リスト表示",
     "Actions" : "アクション",
     "Create event" : "イベントを作成",
     "Show shortcuts" : "概要の表示",
@@ -115,6 +121,7 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
     "Show keyboard shortcuts" : "キーボード ショートカット",
     "Settings & import" : "設定とインポート",
+    "No reminder" : "リマインダーなし",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
     "before at" : "次の時間分早めに通知",
@@ -134,13 +141,18 @@ OC.L10N.register(
     "_hour_::_hours_" : ["時間"],
     "_day_::_days_" : ["日"],
     "_week_::_weeks_" : ["週"],
-    "No reminders yet" : "まだリマインダーはありません",
-    "Free" : "無料",
+    "Available." : "利用可能",
+    "Not available." : "利用できません",
+    "Invitation accepted." : "招待を受け付けました",
+    "Invitation declined." : "招待は辞退しました",
+    "Invitation sent." : "招待が送信されました",
+    "Free" : "空き",
     "Busy (tentative)" : "ビジー (暫定)",
     "Busy" : "ビジー",
     "Out of office" : "オフィス外",
     "Unknown" : "不明",
     "Create Talk room for this event" : "このイベントに通話ルームを作成する",
+    "No attendees yet" : "出席者はまだいません",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
     "Send email" : "メールを送信",
     "Chairperson" : "主宰者",
@@ -149,7 +161,6 @@ OC.L10N.register(
     "Non-participant" : "非参加",
     "Remove attendee" : "出席者を削除",
     "No match found" : "一致するものが見つかりません",
-    "No attendees yet" : "出席者はまだいません",
     "(organizer)" : "（主催者）",
     "Remove color" : "色を削除",
     "Event title" : "イベントタイトル",
@@ -158,6 +169,8 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "{startDate}の{startTime}から",
     "to {endDate}" : "{endDate}まで",
     "to {endDate} at {endTime}" : "{endDate}の{endTime}まで",
+    "Repeat" : "繰り返し",
+    "Save" : "保存",
     "End repeat" : "繰り返し終了",
     "Select to end repeat" : "繰り返しの終了を選択",
     "never" : "なし",
@@ -170,20 +183,19 @@ OC.L10N.register(
     "fifth" : "5日目",
     "second to last" : "2日目から最終日",
     "last" : "最後",
-    "Repeat" : "繰り返し",
     "Repeat every" : "毎日繰り返す",
     "_month_::_months_" : ["月"],
     "_year_::_years_" : ["年"],
     "Monday" : "月曜日",
     "weekday" : "平日",
     "weekend day" : "週末",
-    "Summary" : "要約",
+    "Whiteboard" : "ホワイトボード",
     "More" : "もっと見る",
-    "Save" : "保存",
     "Update" : "アップデート",
     "Update this and all future" : "これ以降を更新",
     "Public calendar does not exist" : "公開カレンダーは存在しません",
-    "Please select a timezone:" : "タイムゾーンを選択してください：",
+    "Maybe the share was deleted or has expired?" : "共有が削除されたか、期限切れの可能性があります",
+    "Please select a time zone:" : "タイムゾーンを選択してください：",
     "Pick a time" : "時間を指定",
     "Pick a date" : "日付を指定",
     "from {formattedDate}" : "{formattedDate}から",
@@ -193,7 +205,7 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
     "Please enter a valid date" : "有効な日付を入力してください",
     "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
-    "Type to search timezone" : "入力してタイムゾーンを検索",
+    "Global" : "グローバル",
     "Personal" : "個人",
     "No more events today" : "今日はこれ以上イベントがありません",
     "No upcoming events" : "今後のイベントはありません",
@@ -201,11 +213,11 @@ OC.L10N.register(
     "[Today]" : "[今日]",
     "[Tomorrow]" : "[明日]",
     "[Yesterday]" : "[昨日]",
+    "[Last] dddd" : "[Last]dddd",
     "Event does not exist" : "イベントは存在しません",
     "Delete this occurrence" : "この出来事を削除",
     "Details" : "詳細",
     "Attendees" : "参加者",
-    "Reminders" : "リマインダー",
     "Close" : "閉じる",
     "Show more details" : "詳細を見る",
     "Download {name}" : "{name}をダウンロード",
@@ -240,6 +252,7 @@ OC.L10N.register(
     "_Every %n month_::_Every %n months_" : ["%n月ごと"],
     "_Every %n year_::_Every %n years_" : ["%n年ごと"],
     "_%n time_::_%n times_" : ["%n回"],
+    "Untitled event" : "無題のイベント",
     "Untitled task" : "タイトルなしタスク",
     "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
     "W" : "W",
@@ -342,7 +355,6 @@ OC.L10N.register(
     "Wine tasting" : "ワイン",
     "Golf" : "ゴルフ",
     "Dinner" : "ディナー",
-    "Lunch" : "ランチ",
-    "Global" : "グローバル"
+    "Lunch" : "ランチ"
 },
 "nplurals=1; plural=0;");
