@@ -29,18 +29,17 @@ OC.L10N.register(
     "Email" : "ელ-ფოსტა",
     "Unknown" : "ამოუცნობი",
     "All day" : "მთელი დღე",
+    "Repeat" : "გამეორება",
+    "Save" : "შენახვა",
     "never" : "არასდროს",
     "after" : "შემდეგ",
-    "Repeat" : "გამეორება",
     "Monday" : "ორშაბათი",
-    "Summary" : "შეჯამება",
     "More" : "უფრო მეტი",
-    "Save" : "შენახვა",
     "Update" : "განახლება",
+    "Global" : "გლობალური",
     "Personal" : "პირადი",
     "Details" : "დეტლაები",
     "Attendees" : "დამსწრეები",
-    "Reminders" : "შემახსენებლები",
     "Close" : "დახურვა",
     "Anniversary" : "დაბადების დღე",
     "Week {number} of {year}" : "კვირა {number} {year}-დან",
@@ -55,7 +54,6 @@ OC.L10N.register(
     "Confirmed" : "დადასტურებლია",
     "Tentative" : "საცდელი",
     "Categories" : "კატეგორიები",
-    "Mail" : "ფოსტა",
-    "Global" : "გლობალური"
+    "Mail" : "ფოსტა"
 },
 "nplurals=2; plural=(n!=1);");
