@@ -18,17 +18,17 @@ OC.L10N.register(
     "Actions" : "Aktiounen",
     "Email" : "Email",
     "Unknown" : "Onbekannt",
+    "Repeat" : "Widderhuelen",
+    "Save" : "Späicheren",
     "never" : "Ni",
     "after" : "No",
-    "Repeat" : "Widderhuelen",
     "Monday" : "Méindeg",
     "More" : "Méi",
-    "Save" : "Späicheren",
     "Update" : "Update",
+    "Global" : "Global",
     "Personal" : "Perséinlech",
     "Details" : "Detailer",
     "Attendees" : "Participanten",
-    "Reminders" : "Erennërungen",
     "Close" : "Zoumaachen",
     "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
     "Daily" : "All Dag",
@@ -38,7 +38,6 @@ OC.L10N.register(
     "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
     "Location" : "Uert",
     "Description" : "Beschreiwung",
-    "Mail" : "Mail",
-    "Global" : "Global"
+    "Mail" : "Mail"
 },
 "nplurals=2; plural=(n != 1);");
