@@ -5,6 +5,7 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Адресата на е-пошта не е правилно внесена",
     "%s has published the calendar »%s«" : "%s Објави календар »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Неочекувана грешка при испраќање на е-пошта. Контактирајте го администраторот.",
+    "Successfully sent email to %1$s" : "Успешно испратена е-пошта до %1$s",
     "Hello," : "Здраво,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Сакаме да те информираме дека %s објави календар »%s«.",
     "Open »%s«" : "Отвори »%s«",
@@ -77,7 +78,10 @@ OC.L10N.register(
     "Creating subscription …" : "Креирање претплата  …",
     "An error occurred, unable to create the calendar." : "Настана грешка, неможе да се креира календар.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Внесете валиден линк (започнувајчи со http://, https://, webcal://, или webcals://)",
-    "Untitled event" : "Неименуван настан",
+    "Name" : "Име",
+    "Deleted" : "Избришани",
+    "Restore" : "Врати",
+    "Delete permanently" : "Избриши",
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
@@ -112,10 +116,12 @@ OC.L10N.register(
     "Limit visible events per view" : "Ограни ги видливите настани по преглед",
     "Show weekends" : "Прикажи викенди",
     "Show week numbers" : "Прикажи броеви на неделите",
+    "Default reminder" : "Стандарден потсетник",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
     "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
     "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
     "Settings & import" : "Параметри & импорт",
+    "No reminder" : "Нема потсетник",
     "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
     "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "before at" : "пред",
@@ -136,8 +142,17 @@ OC.L10N.register(
     "_hour_::_hours_" : ["час","часа"],
     "_day_::_days_" : ["ден","дена"],
     "_week_::_weeks_" : ["недела","недели"],
-    "No reminders yet" : "Сеуште нема потсетници",
+    "Available." : "Достапно.",
+    "Not available." : "Недостапно.",
+    "Checking availability." : "Проверување на достапност.",
+    "Invitation accepted." : "Поканата е прифатена",
+    "Accepted {organizerName}'s invitation." : "Прифатена е покана од {organizerName}.",
+    "Invitation declined." : "Поканата е одбиена.",
+    "Declined {organizerName}'s invitation." : "Одбиена е покана од {organizerName}.",
+    "Invitation sent." : "Испратена е покана.",
+    "Has not responded to {organizerName}'s invitation yet." : "Нема одговор на поканата од {organizerName}.",
     "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
+    "{organizer} (organizer)" : "{organizer} (organizer)",
     "Free" : "Слободен",
     "Busy (tentative)" : "Зафатен (привремено)",
     "Busy" : "Зафатен",
@@ -145,6 +160,7 @@ OC.L10N.register(
     "Unknown" : "Непознат",
     "Create Talk room for this event" : "Креирај соба за разговор за овој настан",
     "Show busy times" : "Прикажи ги зафатените термини",
+    "No attendees yet" : "Сè уште нема присутни",
     "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
     "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "Send email" : "Испрати е-пошта",
@@ -153,9 +169,8 @@ OC.L10N.register(
     "Optional participant" : "Незадолжителен учесник",
     "Non-participant" : "Не-учесник",
     "Remove attendee" : "Откажи присутност",
-    "Search for emails, users, contacts, resources or rooms" : "Пребарувај за е-пошти, корисници, контакти, ресурси или соби",
+    "Search for emails, users or contacts" : "Пребарување на е-пошта адреси, корисници или контакти",
     "No match found" : "Нема совпаѓања",
-    "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
@@ -165,6 +180,8 @@ OC.L10N.register(
     "from {startDate} at {startTime}" : "од {startDate} во {startTime}",
     "to {endDate}" : "до {endDate}",
     "to {endDate} at {endTime}" : "до {endDate} во {endTime}",
+    "Repeat" : "Повтори",
+    "Save" : "Зачувај",
     "End repeat" : "Крај на повторувањето",
     "Select to end repeat" : "Избери крај на повторувањето",
     "never" : "никогаш",
@@ -177,7 +194,6 @@ OC.L10N.register(
     "fifth" : "петти",
     "second to last" : "претпоследен",
     "last" : "последен",
-    "Repeat" : "Повтори",
     "Repeat every" : "Повтори секој",
     "By day of the month" : "По ден во месецот",
     "On the" : "На",
@@ -186,15 +202,13 @@ OC.L10N.register(
     "Monday" : "Понеделник",
     "weekday" : "недели",
     "weekend day" : "ден од викенд",
-    "Summary" : "Резиме",
     "More" : "Повеќе",
-    "Save" : "Зачувај",
     "Update" : "Ажурирај",
     "Update this occurrence" : "Ажурирајте ја оваа можност",
     "Update this and all future" : "Ажурирајте го овој и сите во иднина",
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
-    "Please select a timezone:" : "Изберете временска зона:",
+    "Please select a time zone:" : "Изберете временска зона:",
     "Pick a time" : "Избери време",
     "Pick a date" : "Избери датум",
     "from {formattedDate}" : "од {formattedDate}",
@@ -206,10 +220,11 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} во {formattedTime}",
     "Please enter a valid date" : "Внесете валиден датум",
     "Please enter a valid date and time" : "Внесете валиден датум и време",
-    "Type to search timezone" : "Пребарај временски зони",
+    "Type to search time zone" : "Пребарај временски зони",
+    "Global" : "Глобално",
     "Personal" : "Лично",
-    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
-    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
+    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
+    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
     "No more events today" : "Нема настани за денес",
     "No upcoming events" : "Нема престојни настани",
     "Create a new event" : "Креирајте нов настан",
@@ -222,7 +237,7 @@ OC.L10N.register(
     "Delete this and all future" : "Избришете го овој и сите во иднина",
     "Details" : "Детали",
     "Attendees" : "Присутни",
-    "Reminders" : "Потсетници",
+    "Resources" : "Ресурси",
     "Close" : "Затвори",
     "Show more details" : "Прикажи повеќе детали",
     "Subscribe to {name}" : "Претплатете се на {name}",
@@ -270,8 +285,14 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
     "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
+    "Untitled event" : "Неименуван настан",
     "Untitled task" : "Неименувана задача",
     "Please ask your administrator to enable the Tasks App." : "Замолете го сервер администраторот да ја овозможи апликацијата задачи.",
+    "Prev" : "Предходно",
+    "Next" : "Следно",
+    "Prev year" : "Предходна година",
+    "Next year" : "Следна година",
+    "Year" : "Година",
     "W" : "Н",
     "%n more" : "%n други",
     "No events to display" : "Нема настани за приказ",
@@ -386,7 +407,6 @@ OC.L10N.register(
     "Wine tasting" : "Дегустација на вино",
     "Golf" : "Голф",
     "Dinner" : "Вечера",
-    "Lunch" : "Ручек",
-    "Global" : "Глобално"
+    "Lunch" : "Ручек"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
