@@ -1,6 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is not valid" : "ผู้ให้บริการอีเมลไม่ถูกต้อง",
+    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน %s",
+    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแล",
+    "Successfully sent email to %1$s" : "ส่งอีเมลถึง %1$s สำเร็จ",
+    "Hello," : "สวัสดี",
+    "Open »%s«" : "เปิด »%s«",
     "Cheers!" : "ไชโย!",
     "Calendar" : "ปฏิทิน",
     "Today" : "วันนี้",
@@ -18,17 +24,17 @@ OC.L10N.register(
     "Actions" : "การกระทำ",
     "Email" : "อีเมล",
     "Unknown" : "ไม่ทราบ",
+    "Repeat" : "ทำซ้ำ",
+    "Save" : "บันทึก",
     "never" : "ไม่ต้องเลย",
     "after" : "หลัง",
-    "Repeat" : "ทำซ้ำ",
     "Monday" : "วันจันทร์",
     "More" : "เพิ่มเติม",
-    "Save" : "บันทึก",
     "Update" : "อัพเดท",
+    "Global" : "ทั่วไป",
     "Personal" : "ส่วนตัว",
     "Details" : "รายละเอียด",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
-    "Reminders" : "การแจ้งเตือน",
     "Close" : "ปิด",
     "Anniversary" : "วันครบรอบ",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
@@ -43,7 +49,6 @@ OC.L10N.register(
     "Tentative" : "ชั่วคราว",
     "Presentation" : "งานนำเสนอ",
     "Office" : "สำนักงาน",
-    "Mail" : "จดหมาย",
-    "Global" : "ทั่วไป"
+    "Mail" : "จดหมาย"
 },
 "nplurals=1; plural=0;");
